<?php

namespace App\Console\Commands;

use App\Exports\ReportExport;
use App\Helpers\LogHelper;
use App\Mail\Reports;
use App\Models\Task;
use App\Models\User;
use App\Models\UserTask;
use Illuminate\Console\Command;
use Illuminate\Support\Facades\Mail;
use Maatwebsite\Excel\Facades\Excel;

class UsersExport extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'report:send {task_id} {user_id}';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Notify Admin about users that completed tasks';

    /**
     * Execute the console command.
     *
     * @return int
     */
    public function handle()
    {
        $user_task_id = $this->argument('task_id');
        $user_that_completed_the_task_id = $this->argument('user_id');
        
        $user_task = UserTask::findOrFail($user_task_id);
        $user_that_completed_the_task = User::findOrFail($user_that_completed_the_task_id);
        // LogHelper::logMessageSuccess($user, $user_task);

        // return;
        $group = UserTask::orderBy('task_id')
            ->get()
            ->where('completed', true)
            ->groupBy('task_id');

        Excel::store(new ReportExport($group), 'reports\report.xlsx');

        // $task = Task::finOrFail($this->argument('task'));
        $users = User::permission('receive reports email')->get(); //->pluck('email');
        foreach ($users as $user) {
            Mail::to($user->email)->send(new Reports($user_that_completed_the_task, $user_task));
        }

        return Command::SUCCESS;
    }
}
