<?php

namespace App\Exports;

use App\Models\User;
use Illuminate\Contracts\Support\Responsable;
use Maatwebsite\Excel\Concerns\Exportable;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithColumnWidths;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\WithMapping;
use Maatwebsite\Excel\Events\BeforeSheet;
use PhpOffice\PhpSpreadsheet\Worksheet\PageSetup;

class UsersDeleteExport implements FromCollection, WithHeadings, WithMapping, WithEvents, ShouldAutoSize, Responsable, WithColumnWidths
{
    use Exportable;

    private $usersIDs;
    /**
     * @return \Illuminate\Support\Collection
     */

    public function __construct($usersIDs){
        return $this->usersIDs = $usersIDs;
    }

    public function columnWidths(): array
    {
        return [
            'A' => 1,
            'B' => 1,
            'C' => 1,
            'D' => 1,
            'E' => 1,
            'F' => 1,
            'G' => 1,
            'H' => 1,
            'I' => 1,
            'J' => 1,
            'K' => 1,
            'L' => 1,
        ];
    }

    public function registerEvents(): array
    {
        return  [
            BeforeSheet::class => function (BeforeSheet $event) {
                $event->sheet
                    ->getPageSetup()
                    ->setOrientation(PageSetup::ORIENTATION_LANDSCAPE)
                    ->setpaperSize(1);
            }
        ];
    }

    public function headings(): array
    {
        return [
            'Username',
            'Email'
        ];
    }

    public function map($users):array
    {
        return [
            $users->username,
            $users->email
        ];
    }

    public function collection()
    {
//        dd($this->usersIDs);
//        return User::with('userData', 'authorizations', 'licenses')->find([11]);
        return User::onlyTrashed()->with('userData', 'authorizations', 'licenses')->find($this->usersIDs);
    }
}
