<?php

namespace App\Helpers;

use App\Models\Task;
use App\Models\User;
use App\Models\UserTask;
use App\Models\UserTaskDocument;
use Carbon\Carbon;
use Faker\Core\File;
use Illuminate\Support\Facades\Artisan;
use Illuminate\Support\Facades\File as FacadesFile;

class DocumentHelper
{
    //    get data document for specific task, user and documentId
    public static function getUserTaskDocument($task_id, $user_id, $document_id)
    {

        //        return $task_id;
        return UserTaskDocument::query()
            ->where('task_id', $task_id)
            ->where('user_id', $user_id)
            ->where('document_id', $document_id)
            ->first();
    }

    //    get all data documents for specific user and task, multiple rows
    public static function getUserTaskAllDocument($task_id, $user_id)
    {
        return UserTaskDocument::query()
            ->where('task_id', $task_id)
            ->where('user_id', $user_id)
            ->get();
    }

    public static function checkAllDocumentsUserTaskIsRead($task_id, $user_id)
    {
        $all_documents = self::getUserTaskAllDocument($task_id, $user_id);

        foreach ($all_documents as $document) {
            if ($document->is_read == 0) {
                return;
            }
        }

        $user = User::findOrFail($user_id);
        $task = self::getUserTask($task_id, $user_id);
        $task->update(['completed' => true, 'completed_at' => Carbon::now()->format('Y-m-d H:i:s')]);
        Artisan::queue('report:send', [
            '--user_id' => $user->id,
            '--task_id' => $task->id,
        ]);
    }

    public static function getUserTask($task_id, $user_id)
    {
        return UserTask::where('task_id', $task_id)
            ->where('user_id', $user_id)
            ->first();
    }

    public static function doc_type($doc)
    {
        $doc_type = FacadesFile::extension($doc);
        switch ($doc_type) {
            case 'doc':
            case 'docx':
                return 'docx.png';
            case 'xls':
            case 'xlsx':
                return 'xlsx.png';
            case 'pdf':
                return 'file.svg';
            case 'ppt':
            case 'pptx':
                return 'powerpoint';
            case 'txt':
                return 'text';
            case 'zip':
            case 'rar':
                return 'archive';
            case 'jpg':
            case 'jpeg':
            case 'png':
            case 'gif':
                return 'image-file.svg';
        }
    }

    public static function set_button($document_status)
    {
        switch ($document_status) {
            case false:
                return ['value' => 'false', 'class' => 'from-red-400 via-red-500 to-red-600'];
            case true:
                return ['value' => 'true', 'class' => 'from-green-400 via-green-500 to-green-600'];
        }
    }
}
