<?php

namespace App\Http\Livewire\Dashboard;

use Exception;
use App\Models\User;
use App\Mail\UserInfo;
use Livewire\Component;
use App\Exports\UsersExport;
use Illuminate\Support\Collection;
use Illuminate\Support\Facades\Mail;
use Maatwebsite\Excel\Facades\Excel;

class ShowTask extends Component
{

    public $task;
    public $search;
    //    public Collection $users;
    public Collection $users_task_read;
    public Collection $users_task_unread;
    public Collection $selectedUsers;
    public $selectAll = false;
    public $userModal;
    public $isOpen = 0, $readonly;
    public $modalFormVisable = false;

    public $userModel;
    public $emailModel;
    public $descriptionModel;


    public function mount()
    {
        //        $this->users = $this->task->users;
        $this->users_task_read = $this->task->users;
        $this->users_task_unread = $this->task->users;
        $this->selectedUsers = collect();
        $this->dump_users_not_read = $this->usersNotReadAllDocuments();
        $this->dump_users_read_all = $this->usersReadAllDocuments();
        //        $this->userModal = User::first();
    }

    public function usersReadAllDocuments()
    {

        $dump_not_read = $this->usersNotReadAllDocuments();

        $dump_all = User::with('getUsersAllTaskAndDocuments')
            ->whereHas('getUsersAllTaskAndDocuments', function ($query) {
                return $query->where('task_id', $this->task->id);
            })->get();

        return $dump_all->diff($dump_not_read);
    }

    public function usersNotReadAllDocuments()
    {

        return User::with('getUsersAllTaskAndDocuments')
            ->whereHas('getUsersAllTaskAndDocuments', function ($query) {
                return $query->where('task_id', $this->task->id)
                    ->where('is_read', false);
            })->get();
    }

    public function openUsersModal(User $user)
    {
        $this->openModal();
        $this->userModal = $user;
        $this->emailModel = $user->email;
    }

    public function openModal()
    {
        $this->isOpen = true;
    }

    public function closeModal()
    {
        $this->isOpen = false;
        $this->resetInputFields();
    }

    private function resetInputFields()
    {
        $this->emailModel = '';
        $this->descriptionModel = '';

        //        $this->readonly = '';
    }

    public function sendNotification()
    {

        try {

            //            treba tekstot da se smeni na mejlot da prifakja napishanoto od description i loader na send

            Mail::to($this->emailModel)->send(new UserInfo($this->userModal, $this->task));
            session()->flash('success', 'Notification is sent to ' . $this->userModal->getCredentials());

            $this->closeModal();
            $this->resetInputFields();
        } catch (Exception $e) {
            //            dd($e->getMessage());
            session()->flash('danger', 'Something went wrong ' . $e->getMessage());
        }
    }

    public function export($ext)
    {

        if ($this->selectAll) {
            $this->selectAll = false;
            $this->selectedUsers = collect([]);

            if ($this->role) {
                return Excel::download(new UsersExport(
                    User::where('username', 'like', '%' . $this->search . '%')
                        ->orWhere('email', 'like', '%' . $this->search . '%')
                        ->pluck('id')
                ), 'all_users.' . $ext);
            } else {
                return Excel::download(new UsersExport(
                    User::where('username', 'like', '%' . $this->search . '%')
                        ->orWhere('email', 'like', '%' . $this->search . '%')
                        ->pluck('id')
                ), 'all_users.' . $ext);
            }
        } else {

            $this->selectAll = false;
            return Excel::download(new UsersExport($this->getSelectedUsers()), 'users.' . $ext);
        }
    }

    private function getSelectedUsers()
    {
        return $this->selectedUsers->filter(fn ($u) => $u)->keys();
    }

    public function render()
    {
        return view('livewire.dashboard.show-task');
    }
}
