<?php

namespace App\Http\Livewire\JobAuthorization;

use App\Helpers\LogHelper;
use Livewire\Component;
use App\Models\JobAuthorization;

class JobAuthorizationForm extends Component
{
    public $job_authorizations, $name, $description, $authorization_number, $job_authorization_id, $readonly;
    public $isOpen = 0, $number = 0;

    public function render()
    {
        $this->job_authorizations = JobAuthorization::all();
        return view('livewire.job-authorization.job-authorization-form');
    }

    public function create()
    {
        $this->resetInputFields();
        $this->openModal();
    }

    public function openModal()
    {
        $this->isOpen = true;
    }

    public function closeModal()
    {
        $this->isOpen = false;
        $this->resetInputFields();
    }

    private function resetInputFields()
    {
        $this->name = '';
        $this->description = '';
        $this->authorization_number = '';
        $this->job_authorization_id = '';
        $this->readonly = '';
    }

    public function store()
    {
        $this->validate([
            'name' => 'required',
            'description' => 'required',
        ]);

        try{
            $job_authorization = JobAuthorization::updateOrCreate(['id' => $this->job_authorization_id], [
                'name' => $this->name,
                'description' => $this->description,
                'authorization_number' => $this->authorization_number,
            ]);

            $message = $this->job_authorization_id ? __('messages.Job authorization') . " $this->name " . __('messages.Updated Successfully.') : __('messages.Job authorization') . " $this->name " . __('messages.Created Successfully.');
            $messageLog = $this->job_authorization_id ? "Работната авторизација  $this->name Успешно е Ажурирана." : "Работната авторизација  $this->name Успешно е Креирана.";

            session()->flash(
                'message',
                $message
            );

            $this->closeModal();
            $this->resetInputFields();

            $data = ['job_authorization' => $job_authorization];
            LogHelper::logInfo($messageLog, $data);

        } catch (\Exception $e) {
            $this->closeModal();
            $this->resetInputFields();
            $message = $e->getMessage();
            $data = ['job_name' => $this->name, 'error' => $e->getMessage()];
            LogHelper::logMessageError($message, $data);
        }
    }

    public function edit($id)
    {
        $job_authorization = JobAuthorization::findOrFail($id);
        $this->job_authorization_id = $id;
        $this->name = $job_authorization->name;
        $this->description = $job_authorization->description;
        $this->authorization_number = $job_authorization->authorization_number;

        $this->openModal();
    }

    public function show($id)
    {
        $job_authorization = JobAuthorization::findOrFail($id);
        $this->job_authorization_id = $id;
        $this->name = $job_authorization->name;
        $this->description = $job_authorization->description;
        $this->authorization_number = $job_authorization->authorization_number;

        $this->readonly = 'readonly';

        $this->openModal();
    }

    public function delete($id)
    {
        $job_authorization = JobAuthorization::findOrFail($id);
        $job_authorization_name = $job_authorization->name;
        $job_authorization->delete();
        $message = __('messages.Job authorization') . " $job_authorization_name " . __('messages.Deleted Successfully') ;
        session()->flash('message', $message);

        $messageLog = "Работната авторизација $job_authorization_name успешно е избришана" ;
        $data = ['job_authorization_name' => $job_authorization_name, 'message' => $message];
        LogHelper::logInfo($messageLog, $data);
    }
}
