<?php

namespace App\Http\Livewire\JobLicense;

use App\Helpers\LogHelper;
use App\Models\JobLicense;
use Livewire\Component;

class JobLicenseForm extends Component
{
    public $job_licenses, $name, $description, $license_number, $job_license_id, $readonly;
    public $isOpen = 0, $number = 0;

    public function render()
    {
        $this->job_licenses = JobLicense::all();
        return view('livewire.job-license.job-license-form');
    }

    public function create()
    {
        $this->resetInputFields();
        $this->openModal();
    }

    public function openModal()
    {
        $this->isOpen = true;
    }

    public function closeModal()
    {
        $this->isOpen = false;
        $this->resetInputFields();
    }

    private function resetInputFields()
    {
        $this->name = '';
        $this->description = '';
        $this->license_number = '';
        $this->job_license_id = '';
        $this->readonly = '';
    }

    public function store()
    {

        $this->validate([
            'name' => 'required',
            'description' => 'required',
        ]);

        try{
            $job_licence = JobLicense::updateOrCreate(['id' => $this->job_license_id], [
                'name' => $this->name,
                'description' => $this->description,
                'license_number' => $this->license_number,
            ]);

            $message = $this->job_license_id ? __('messages.Job license') . " $job_licence->name " . __('messages.Updated Successfully.') : __('messages.Job license') . " $job_licence->name " . __('messages.Created Successfully.');
            $messageLog = $this->job_license_id ? "Работната лиценца $job_licence->name Успешно е Ажурирана." : "Работната лиценца $job_licence->name Успешно е Креирана.";

            session()->flash(
                'message',
                $message
            );

            $this->closeModal();
            $this->resetInputFields();

            $data = ['job_licence' => $job_licence];
            LogHelper::logInfo($messageLog, $data);

            } catch (\Exception $e) {
                $this->closeModal();
                $this->resetInputFields();
                $message = $e->getMessage();
                $data = ['job_licence_name' => $this->name, 'error' => $e->getMessage()];
                LogHelper::logMessageError($message, $data);
            }
    }

    public function edit($id)
    {
        $job_license = JobLicense::findOrFail($id);
        $this->job_license_id = $id;
        $this->name = $job_license->name;
        $this->description = $job_license->description;
        $this->license_number = $job_license->license_number;

        $this->openModal();
    }

    public function show($id)
    {
        $job_license = JobLicense::findOrFail($id);
        $this->job_license_id = $id;
        $this->name = $job_license->name;
        $this->description = $job_license->description;
        $this->license_number = $job_license->license_number;

        $this->readonly = 'readonly';

        $this->openModal();
    }

    public function delete($id)
    {
        $job_licence = JobLicense::findOrFail($id);
        $job_licence_name = $job_licence->name;
        $job_licence->delete();
        $message = __('messages.Job license') . " $job_licence_name " . __('messages.Deleted Successfully');
        $messageLog = "Работната лиценца $job_licence_name е успешно избришана";
        session()->flash('message', $message);
        $data = ['job_licence_name' => $job_licence_name, 'message' => $message];
        LogHelper::logInfo($messageLog, $data);
    }
}
