<?php

namespace App\Http\Livewire\Users;

use App\Models\User;
use Livewire\Component;
use App\Models\UserData;
use App\Helpers\LogHelper;
use App\Models\JobLicense;
use App\Models\UserLicense;
use App\Models\JobDescription;
use App\Models\JobAuthorization;
use App\Models\UserAuthorization;
use Illuminate\Support\Facades\DB;
use Spatie\Permission\Models\Role;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Password;

class CreateForm extends Component
{
    public $username = "";
    public $email;
    public $first_name = "";
    public $last_name = "";
    public $phone;
    public $password;
    public $password_confirmation;

    public $jobDescription;
    public $jobDescriptions = [];

    public $jobLicenses = [];
    public $selectedJobLicenses = [];
    public $jobAuthorizations = [];
    public $selectedJobAuthorizations = [];
    public $roles = [];
    public $selectedRoles = [];

    protected $rules = [
        'username' => 'required',
        'email' => 'required|email',
        'first_name' => 'required',
        'last_name' => 'required',
        'phone' => 'required',
        'jobDescription' => 'required',
        'selectedJobLicenses' => 'required',
        'selectedRoles' => 'required',
        'selectedJobAuthorizations' => 'required',
    ];

    public function mount()
    {
        $this->jobDescriptions = JobDescription::all();
        $this->jobLicenses = JobLicense::all();
        $this->roles = Role::all();
        $this->jobAuthorizations = JobAuthorization::all();
    }

    public function submit()
    {
        $this->validate();

        DB::beginTransaction();
        try {
            $user = User::create([
                'username' => $this->username,
                'email' => $this->email,
                'password' => Hash::make($this->email),
            ]);

            $userData = UserData::create([
                'user_id' => $user->id,
                'first_name' => $this->first_name,
                'last_name' => $this->last_name,
                'initials' => mb_convert_case(mb_substr($this->first_name, 0, 1, 'UTF-8') . mb_substr($this->last_name, 0, 1, 'UTF-8'),MB_CASE_UPPER,"UTF-8"),
                'job_description_id' => $this->jobDescription,
                'phone' => $this->phone,
            ]);

            $user->assignRole($this->selectedRoles);

            foreach ($this->selectedJobAuthorizations as $authorization) {
                UserAuthorization::create([
                    'user_id' => $user->id,
                    'job_authorization_id' => $authorization
                ]);
            }

            foreach ($this->selectedJobLicenses as $license) {
                UserLicense::create([
                    'user_id' => $user->id,
                    'job_license_id' => $license
                ]);
            }

            DB::commit();

            $message = __('messages.New User') . " $this->first_name $this->last_name " . __('messages.is Created');
            $messageLog = "Нов корисник $this->first_name $this->last_name е креиран";
            $data = ['user' => $userData];
            LogHelper::logInfo($messageLog, $data);

            $this->reset();
            $this->resetErrorBag();

            Password::sendResetLink(['email' => $user->email]);

            redirect()->route('users.index')->with('new_message', $message);
        } catch (\Exception $e) {
            DB::rollback();
            $message = $e->getMessage();
            $data = ['error' => $e->getMessage()];
            LogHelper::logMessageError($message, $data);

            $this->dispatchBrowserEvent('notifyUser', [
                'style' => 'danger',
                'status' =>  __('messages.Error'),
                'message' => $e->getMessage()
            ]);
        }
    }

    public function render()
    {
        return view('livewire.users.create-form');
    }
}
