<?php

namespace App\Jobs;

use App\Mail\AdminTaskInfo;
use App\Mail\UserInfo;
use App\Models\User;
use App\Notifications\TaskReminderNotification;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldBeUnique;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;
use Illuminate\Support\Facades\Mail;

class TaskReminderAdminJob implements ShouldQueue
{
    use Dispatchable, InteractsWithQueue, Queueable, SerializesModels;

    /**
     * Create a new job instance.
     *
     * @return void
     */
    public $task;

    public function __construct($task)
    {
        $this->task = $task;
    }

    /**
     * Execute the job.
     *
     * @return void
     */
    public function handle()
    {
        $admin_users = User::getAllAdminsAndSupervisors();

        foreach ($admin_users as $user) {
            $task_info = [
                'task' => $this->task,
                'user' => $user,
            ];

            Mail::to($user->email)->send(new AdminTaskInfo($user, $this->task));
        }
        $this->job->getJobId();
    }
}
