<?php

namespace App\Providers;

use App\Actions\Jetstream\DeleteUser;
use App\Helpers\LogHelper;
use App\Models\User;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;

use Illuminate\Support\ServiceProvider;
use Laravel\Fortify\Fortify;
use Laravel\Jetstream\Jetstream;

class JetstreamServiceProvider extends ServiceProvider
{
    /**
     * Register any application services.
     *
     * @return void
     */
    public function register()
    {
        //
    }

    /**
     * Bootstrap any application services.
     *
     * @return void
     */
    public function boot(Request $request)
    {
        $this->configurePermissions();

        Jetstream::deleteUsersUsing(DeleteUser::class);


//        Jetstream custom authentication for adding logs
        Fortify::authenticateUsing(function (Request $request) {
            $user = User::with('userData')->where('email', $request->email)->first();
            if ($user && Hash::check($request->password, $user->password)) {
                    $data = ['user' => $user];
                    if($user->userData){
                        $credentials = $user->getCredentials();
                    }else{
                        $credentials = $user->username;
                    }
                    $message = "User $credentials has logged in" ;
                    LogHelper::logInfo($message, $data);

                return $user;
            }
        });




    }

    /**
     * Configure the permissions that are available within the application.
     *
     * @return void
     */
    protected function configurePermissions()
    {
        Jetstream::defaultApiTokenPermissions(['read']);

        Jetstream::permissions([
            'create',
            'read',
            'update',
            'delete',
        ]);
    }
}
