<?php

namespace Database\Seeders;

use App\Models\JobDescription;
use App\Models\User;
use App\Models\UserData;
use Illuminate\Database\Seeder;
use Spatie\Permission\Models\Role;
use Spatie\Permission\Models\Permission;

class UserSeeder extends Seeder
{
    /**
     * Run the database seeds.
     *
     * @return void
     */
    public function run()
    {
        //Admin User
        $admin = User::create([
            'username' => 'admin',
            'email' => 'admin@admin.com',
            'password' => bcrypt('password'),
        ]);

        JobDescription::create([
            'name' => 'Test',
            'description' => 'Test description',
        ]);

        UserData::create([
            'user_id' => $admin->id,
            'first_name' => 'admin',
            'last_name' => 'adminovski',
            'initials' => 'AA',
            'phone' => '389123456789',
            'job_description_id' => 1,
        ]);

        //Non Admin Users
        $supervisor = User::create([
            'username' => 'supervisor',
            'email' => 'supervisor@supervisor.com',
            'password' => bcrypt('password'),
        ]);

        UserData::create([
            'user_id' => $supervisor->id,
            'first_name' => 'supervisor',
            'last_name' => 'supervisorski',
            'initials' => 'SS',
            'phone' => '389213456788',
            'job_description_id' => 1,
        ]);

        $user = User::create([
            'username' => 'user',
            'email' => 'user@user.com',
            'password' => bcrypt('password'),
        ]);

        UserData::create([
            'user_id' => $user->id,
            'first_name' => 'user',
            'last_name' => 'userovski',
            'initials' => 'UU',
            'phone' => '389213456787',
            'job_description_id' => 1,
        ]);

        //Roles
        $adminRole = Role::create(['name' => 'admin']);
        $supervisorRole = Role::create(['name' => 'supervisor']);
        $userRole = Role::create(['name' => 'user']);

        $manageUsers = Permission::create(['name' => 'manage users']);
        $manageTasks = Permission::create(['name' => 'manage tasks']);
        $manageJobLicenses = Permission::create(['name' => 'manage job licenses']);
        $manageJobAuthorizations = Permission::create(['name' => 'manage job authorizations']);
        $manageJobDescriptions = Permission::create(['name' => 'manage job descriptions']);
        $manageUserRoles = Permission::create(['name' => 'manage user roles']);
        $manageUserPermissions = Permission::create(['name' => 'manage user permissions']);
        $manageLogs = Permission::create(['name' => 'manage logs']);

        $exportUsers = Permission::create(['name' => 'export users']);

        $restoreArchivedUsers = Permission::create(['name' => 'restore archived users']);
        $restoreArchivedTasks = Permission::create(['name' => 'restore archived tasks']);
        $receiveReportsEmail = Permission::create(['name' => 'receive reports email']);
        $exportDataBase = Permission::create(['name' => 'export database']);

        $viewUserTasks = Permission::create(['name' => 'view user tasks']);


        //Assign permissions to admin user
        $adminRole->syncPermissions([
            $manageUsers,
            $manageTasks,
            $manageJobLicenses,
            $manageJobAuthorizations,
            $manageJobDescriptions,
            $manageUserRoles,
            $manageUserPermissions,
            $manageLogs,
            $exportUsers,
            $restoreArchivedUsers,
            $restoreArchivedTasks,
            $viewUserTasks,
            $receiveReportsEmail,
            $exportDataBase
        ]);

        //Assign permissions to non admin users
        $supervisorRole->syncPermissions([
            $manageUsers,
            $manageTasks,
            $viewUserTasks
        ]);

        $userRole->syncPermissions([
            $viewUserTasks
        ]);

        $admin->assignRole($adminRole);
        $supervisor->assignRole($supervisorRole);
        $user->assignRole($userRole);
    }
}
