<?php

use App\Http\Controllers\AdminDashboardController;
use App\Http\Controllers\LogsController;
use App\Models\Task;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\UserController;
use App\Http\Controllers\TasksController;
use App\Http\Controllers\JobLicenseController;
use App\Http\Controllers\LangController;

use App\Http\Controllers\JobDescriptionController;
use App\Http\Controllers\JobAuthorizationController;
use App\Http\Livewire\Tables\TaskArchiveDatatables;
use App\Models\JobDescription;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::middleware([
    'auth:sanctum',
    config('jetstream.auth_session'),
    'verified'
])->group(function () {
    Route::get('/', [AdminDashboardController::class, 'home'])->name('home');

    // Route::get('/dashboard', function () {
    //     return view('dashboard');
    // })->name('dashboard');
    // Route::get('/reports', function () {
    //     return view('reports');
    // })->name('reports');
    Route::get('/other_data', function () {
        return view('other_data');
    })->name('other_data');
    Route::get('/finance', function () {
        return view('finance');
    })->name('finance');

    Route::group([
        'middleware' => ['permission:manage users'],
        'prefix' => 'users',
        'as' => 'users.',
        'controller' => UserController::class
    ], function () {
        Route::get('/', 'index')->name('index');
        Route::get('/create', 'create')->name('create');
        // Route::get('/edit/{id}', 'edit')->name('edit');
        Route::get('/archived', 'archived')->name('archived');
    });

    Route::group([
        'middleware' => ['permission:restore archived users'],
        'prefix' => 'users',
        'as' => 'users.',
        'controller' => UserController::class
    ], function () {
        Route::get('/archived', 'archived')->name('archived');
    });

    Route::group([
        'middleware' => ['permission:manage user roles'],
        'prefix' => 'users',
        'as' => 'users.',
    ], function () {
        Route::get('/roles', function () {
            return view('user-manager.roles');
        })->name('roles');
    });

    Route::group([
        'middleware' => ['permission:manage user permissions'],
        'prefix' => 'users',
        'as' => 'users.',
    ], function () {
        Route::get('/permissions', function () {
            return view('user-manager.permissions');
        })->name('permissions');
    });

    Route::group([
        'middleware' => ['permission:manage tasks'],
        'prefix' => 'tasks',
        'as' => 'tasks.',
        'controller' => TasksController::class
    ], function () {
        Route::get('/', 'index')->name('index');
        Route::get('/create', 'create')->name('create');
        Route::get('/edit/{id}', 'edit')->name('edit');
    });

    Route::group([
        'middleware' => ['permission:restore archived tasks'],
        'prefix' => 'tasks',
        'as' => 'tasks.',
        'controller' => TasksController::class
    ], function () {
        Route::get('/archived', 'archived')->name('archived');
    });

    Route::group([
        'middleware' => ['permission:view user tasks'],
        'prefix' => 'tasks',
        'as' => 'tasks.',
        'controller' => TasksController::class
    ], function () {
        Route::get('/', 'index')->name('index');
        Route::get('/show/{id}', 'show')->name('show');
    });

    Route::group([
        'middleware' => ['permission:view user tasks'],
        'prefix' => 'dashboard',
        'as' => 'dashboard.',
        'controller' => AdminDashboardController::class
    ], function () {
        Route::get('/', 'index')->name('index');
        Route::get('/task-show/{id}', 'show_task')->name('task.show');
    });

    Route::group([
        'middleware' => ['permission:manage job authorizations'],
        'prefix' => 'job_authorization',
        'as' => 'job_authorization.',
        'controller' => JobAuthorizationController::class
    ], function () {
        Route::get('/', 'index')->name('index');
    });

    Route::group([
        'middleware' => ['permission:manage_job_description'],
        'prefix' => 'job_description',
        'as' => 'job_description.',
        'controller' => JobDescriptionController::class
    ], function () {
        Route::get('/', 'index')->name('index');
    });

    Route::group([
        'middleware' => ['permission:manage job licenses'],
        'prefix' => 'job_license',
        'as' => 'job_license.',
        'controller' => JobLicenseController::class
    ], function () {
        Route::get('/', 'index')->name('index');
    });

    Route::group([
        'middleware' => ['permission:manage logs'],
        'prefix' => 'logs',
        'as' => 'logs.',
        'controller' => LogsController::class
    ], function () {
        Route::get('/', 'index')->name('index');
    });

    Route::group([
        'middleware' => ['permission:export database'],
        'prefix' => 'db',
        'as' => 'db.',
        'controller' => AdminDashboardController::class
    ], function () {
        Route::get('/', 'export_database')->name('export');
    });
});

Route::get('/lang/{lang}', [LangController::class, 'changeLange'])->name('change.lang');
